@@ -16,7 +16,7 @@
 
 # Copyrights (C)
 # for this R-port: 
-#   1999 - 2006, Diethelm Wuertz, GPL
+#   1999 - 2007, Diethelm Wuertz, GPL
 #   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
 #   info@rmetrics.org
 #   www.rmetrics.org
@@ -30,14 +30,14 @@
 ################################################################################
 # FUNCTION:            DESCRIPTION:    
 #  'fDISTFIT'           S4 Class representation
-#  print.fDISTFIT       Prints Results from a Fitted Distribution
-# FUNCTION:            NORMAL DISTRIBUTION:
-#  .normFit             Fits parameters of a Normal density
-# FUNCTION:            STUDENT DISTRIBUTION:
+#  show.fDISTFIT        Prints Results from a Fitted Distribution
+# FUNCTION:            NORMAL AND STUDENT-t DISTRIBUTION:
+#  nFit                 Fits parameters of a Normal density
 #  tFit                 Fits parameters of a Student-t density
 # FUNCTION:            STABLE DISTRIBUTION:
 #  stableFit            Fits parameters of a stable density
 #  .phiStable            Creates contour table for McCulloch estimators
+#  .PhiStable            Contour table created by .phiStable()
 #  .qStableFit           Estimates stable parameters by McCulloch approach
 #  .mleStableFit         Estimates stable parameters by MLE approach
 # FUNCTION:            GENERALIZED DISTRIBUTION:
@@ -48,8 +48,10 @@
 
 
 ################################################################################   
+# FUNCTION:            DESCRIPTION:
 #  'fDISTFIT'           S4 Class Representation
-#  print.fDISTFIT       Prints Results from a Fitted Distribution
+#  .print.fDISTFIT       Prints Results from a Fitted Distribution
+#  show.fDISTFIT         Prints Results from a Fitted Distribution
 
 
 setClass("fDISTFIT", 
@@ -67,53 +69,53 @@ setClass("fDISTFIT",
 # ------------------------------------------------------------------------------
 
 
-print.fDISTFIT =
-function(x, ...)
+show.fDISTFIT = 
+function(object)
 {   # A function implemented by Diethelm Wuertz
-
+    
     # Description:
     #   Prints Results from a Fitted Distribution
     
-    # Changes:
-    #
-    
     # FUNCTION:
     
-    # Fit:
-    object = x@fit
-    
     # Title:
     cat("\nTitle:\n ")
-    cat(x@title, "\n")
+    cat(object@title, "\n")
     
     # Call:
     cat("\nCall:\n ")
-    cat(paste(deparse(x@call), sep = "\n", collapse = "\n"), 
+    cat(paste(deparse(object@call), sep = "\n", collapse = "\n"), 
         "\n", sep = "")
       
     # Model: 
-    cat("\nModel:\n ", x@model, "\n", sep = "")
+    cat("\nModel:\n ", object@model, "\n", sep = "")
     
     # Estimate:
     cat("\nEstimated Parameter(s):\n")
-    print(x@fit$estimate)
+    print(object@fit$estimate)
         
     # Description:
     cat("\nDescription:\n ")
-    cat(x@description, "\n\n")
-        
+    cat(object@description, "\n\n")
+    
     # Return Value:
     invisible()
 }
 
 
+# ------------------------------------------------------------------------------
+
+
+setMethod("show", "fDISTFIT", show.fDISTFIT)
 
 
 ################################################################################
-#  .normFit             Fits parameters of a Normal density
+# FUNCTION:            NORMAL AND STUDENT-t DISTRIBUTION:
+#  nFit                 Fits parameters of a Normal density
+#  tFit                 Fits parameters of a Student-t density
 
 
-.normFit = 
+nFit = 
 function(x, doplot = TRUE, span = "auto", title = NULL, 
 description = NULL, ...)
 {   # A function implemented by Diethelm Wuertz
@@ -126,10 +128,7 @@ description = NULL, ...)
     #   Function Calls: nlminb(), density() 
     #   The function normFit() can be found in the Rmetrics
     #       chapter GarchDistributions.
-    
-    # Changes:
-    #
-    
+   
     # FUNCTION:
     
     # Transform:
@@ -160,13 +159,13 @@ description = NULL, ...)
         plot(x, log(y), xlim = c(span[1], span[length(span)]),  
             ylim = ylim, type = "p", xlab = "x", ylab = "log f(x)", ...)
         title("NORMAL: Parameter Estimation")
-        lines(x = span, y = log(y.points), col = "steelblue4") 
+        lines(x = span, y = log(y.points), col = "steelblue") 
         if (exists("grid")) grid()  
     }
     
     # Add Title and Description:
     if (is.null(title)) title = "Student-t Parameter Estimation"
-    if (is.null(description)) description = as.character(date())
+    if (is.null(description)) description = .description()
         
     # Fit:
     fit = list(estimate = c(mean = mean, sd = sd)) 
@@ -178,12 +177,11 @@ description = NULL, ...)
         data = as.data.frame(x.orig),
         fit = fit,
         title = as.character(title), 
-        description = as.character(description) )
+        description = .description() )
 }
 
 
-################################################################################
-#  tFit                 Fits parameters of a Student-t density
+# ------------------------------------------------------------------------------
 
 
 tFit = 
@@ -201,9 +199,6 @@ title = NULL, description = NULL, ...)
     # Example:
     #   tFit(rt(1000, df=4))
     
-    # Changes:
-    #
-    
     # FUNCTION:
     
     # Transform:
@@ -251,13 +246,13 @@ title = NULL, description = NULL, ...)
         plot(x, log(y), xlim = c(span[1], span[length(span)]), 
             ylim = ylim, type = "p", xlab = "x", ylab = "log f(x)", ...)
         title("STUDENT-T: Parameter Estimation")
-        lines(x = span, y = log(y.points), col = "steelblue4") 
+        lines(x = span, y = log(y.points), col = "steelblue") 
         if (exists("grid")) grid()  
     }
     
     # Add Title and Description:
     if (is.null(title)) title = "Student-t Parameter Estimation"
-    if (is.null(description)) description = as.character(date())
+    if (is.null(description)) description = .description()
         
     # Fit:
     fit = list(estimate = c(df = r$estimate), minimum = -r$minimum, 
@@ -270,13 +265,15 @@ title = NULL, description = NULL, ...)
         data = as.data.frame(x.orig),
         fit = fit,
         title = as.character(title), 
-        description = as.character(description) )
+        description = .description() )
 }
 
 
 ################################################################################
+# FUNCTION:            STABLE DISTRIBUTION:
 #  stableFit            Fits parameters of a stable density
 #  .phiStable            Creates contour table for McCulloch estimators
+#  .PhiStable            Contour table created by .phiStable()
 #  .qStableFit           Estimates stable parameters by McCulloch approach
 #  .mleStableFit         Estimates stable parameters by MLE approach
 
@@ -289,10 +286,7 @@ title = NULL, description = NULL)
 
     # Description 
     #   Stable Parameter Estimation
-    
-    # Changes:
-    #
-    
+
     # FUNCTION:
 
     # Start Values: Use Quantile Method:
@@ -329,10 +323,7 @@ function()
     
     # Note:
     #   Stable Distribution - delta=1 and gamma=0 fixed!
-    
-    # Changes:
-    #
-    
+ 
     # FUNCTION:
     
     # Settings:
@@ -386,26 +377,255 @@ function()
 # ------------------------------------------------------------------------------
 
 
+.PhiStable =
+structure(
+    #  Contour table created by .phiStable()
+    list(
+    
+    Phi1 = structure(c(28.1355600962322, 15.7196640771722, 
+    10.4340722145276, 7.72099712337154, 6.14340919629241, 5.14081963876442, 
+    4.45927409495436, 3.97057677836415, 3.60450193720703, 3.31957820409758, 
+    3.09091185492284, 2.9029090263133, 2.74659551412658, 2.61782756430233, 
+    2.51560631141019, 2.47408801877228, 2.44525363752631, 28.3483300097440, 
+    15.8035063527296, 10.4727953966709, 7.74141823634036, 6.15576314177463, 
+    5.14915506532249, 4.46531988542058, 3.97505189771183, 3.60736868847651, 
+    3.32104702700423, 3.09111342044363, 2.90219825204304, 2.74552084086904, 
+    2.61707392900167, 2.51531961206501, 2.47401179006119, 2.44525268403340, 
+    28.9048147202382, 16.0601313263480, 10.6117049719320, 7.8237753182648, 
+    6.20955682299195, 5.18679961805621, 4.49216000186678, 3.99373973242068, 
+    3.61933010719953, 3.3275594162867, 3.09331226057454, 2.90155994459038, 
+    2.74368539137288, 2.61555847928520, 2.51479444686423, 2.47387109904253, 
+    2.44525093764076, 29.8026200973137, 16.5596243974224, 10.9360864131028, 
+    8.04563520952583, 6.35889612112486, 5.28397230078563, 4.55431822343012, 
+    4.03266384946799, 3.64246979110989, 3.33973615437707, 3.09810405845187, 
+    2.90191073816964, 2.7422687239301, 2.61421528380001, 2.51433181630644, 
+    2.47374639426837, 2.44524854839106, 31.1711919144382, 17.3256645589998, 
+    11.4257682914949, 8.37916374365985, 6.59111369941092, 5.4435297531592, 
+    4.65827423282770, 4.09593909348039, 3.67827370972420, 3.35788028768518, 
+    3.10538249512478, 2.90322430476313, 2.7411383952518, 2.61307358265729, 
+    2.51393064512464, 2.47363793686619, 2.44524473760244, 33.1948934984822, 
+    18.4071500759968, 12.0794579487667, 8.80181848446003, 6.8744516193679, 
+    5.6351929385469, 4.78568154439060, 4.17585254205654, 3.72404890551037, 
+    3.38077811930023, 3.11457663716798, 2.90522469731234, 2.74043557937936, 
+    2.61209710262770, 2.51359601849030, 2.47354590407541, 2.44523688699559, 
+    35.9578028398622, 19.7936882741385, 12.8664734285429, 9.28349135864713, 
+    7.18278427917665, 5.83729171895546, 4.91779143967590, 4.25960094973301, 
+    3.77307337255403, 3.4057709031586, 3.12469898537975, 2.90767817230573, 
+    2.7399388028832, 2.61130578115398, 2.51330169831474, 2.47347041290067, 
+    2.4452243360266, 38.9647018181828, 21.2269841758554, 13.6587928142908, 
+    9.75737930074977, 7.47910500668215, 6.02679068365276, 5.03975173429821, 
+    4.33641171958119, 3.81844774991854, 3.42948489228359, 3.13453596844362, 
+    2.91006724722144, 2.73965159366498, 2.61068126597691, 2.51309087992836, 
+    2.47342375837911, 2.44524639012562, 41.7818369588849, 22.4602363370435, 
+    14.3128567516975, 10.1435099877839, 7.72005687380391, 6.18048140792379, 
+    5.13779081982581, 4.39769218775219, 3.85488105109873, 3.44880791704519, 
+    3.14262443869137, 2.91215029990006, 2.73947335432536, 2.61026149741526, 
+    2.51293721037603, 2.47333463795113, 2.44523871005695, 43.8597008728084, 
+    23.308181530155, 14.7432127411421, 10.3930748979735, 7.87518470289541, 
+    6.2796283727218, 5.20095216574708, 4.43724315622136, 3.87838777226609, 
+    3.46128790559551, 3.14792806986726, 2.91355836113947, 2.7394048824397, 
+    2.60999397178590, 2.51287974154683, 2.4733261698261, 2.44523291863013, 
+    44.6351177921226, 23.612190997173, 14.8937659530932, 10.4791077126402, 
+    7.9285095195091, 6.31375867971341, 5.2228691158165, 4.45085115209764, 
+    3.88645952709398, 3.46562279514434, 3.14978921717977, 2.91402779433739, 
+    2.73939000980242, 2.60993524495366, 2.51289337121820, 2.47330017392183, 
+    2.44524525291192, 43.8597008728085, 23.3081815301550, 14.7432127411420, 
+    10.3930748979735, 7.87518470289542, 6.2796283727218, 5.20095216574709, 
+    4.43724315622136, 3.87838777226609, 3.46128790559551, 3.14792806986726, 
+    2.91355836113947, 2.7394048824397, 2.60999397178590, 2.51287974154683, 
+    2.4733261698261, 2.44523291863013, 41.7818369588849, 22.4602363370436, 
+    14.3128567516975, 10.1435099877840, 7.72005687380392, 6.18048140792379, 
+    5.13779081982581, 4.39769218775219, 3.85488105109874, 3.44880791704519, 
+    3.14262443869137, 2.91215029990006, 2.73947335432536, 2.61026149741526, 
+    2.51293721037603, 2.47333463795113, 2.44523871005695, 38.9647018181828, 
+    21.2269841758554, 13.6587928142909, 9.75737930074976, 7.47910500668216, 
+    6.02679068365277, 5.0397517342982, 4.33641171958119, 3.81844774991854, 
+    3.42948489228359, 3.13453596844362, 2.91006724722144, 2.73965159366498, 
+    2.61068126597691, 2.51309087992836, 2.47342375837911, 2.44524639012562, 
+    35.9578028398623, 19.7936882741384, 12.8664734285429, 9.28349135864712, 
+    7.18278427917667, 5.83729171895546, 4.91779143967590, 4.25960094973301, 
+    3.77307337255403, 3.4057709031586, 3.12469898537975, 2.90767817230572, 
+    2.7399388028832, 2.61130578115398, 2.51330169831474, 2.47347041290067, 
+    2.4452243360266, 33.1948934984822, 18.4071500759967, 12.0794579487667, 
+    8.80181848446, 6.8744516193679, 5.6351929385469, 4.78568154439059, 
+    4.17585254205653, 3.72404890551037, 3.38077811930023, 3.11457663716797, 
+    2.90522469731234, 2.74043557937936, 2.61209710262770, 2.51359601849030, 
+    2.47354590407541, 2.44523688699559, 31.1711919144381, 17.3256645589999, 
+    11.4257682914948, 8.37916374365983, 6.59111369941092, 5.44352975315921, 
+    4.65827423282769, 4.09593909348039, 3.67827370972420, 3.35788028768518, 
+    3.10538249512478, 2.90322430476312, 2.7411383952518, 2.61307358265729, 
+    2.51393064512464, 2.47363793686619, 2.44524473760245, 29.8026200973136, 
+    16.5596243974222, 10.9360864131028, 8.04563520952581, 6.35889612112487, 
+    5.28397230078562, 4.55431822343012, 4.03266384946799, 3.64246979110989, 
+    3.33973615437707, 3.09810405845187, 2.90191073816964, 2.7422687239301, 
+    2.61421528380001, 2.51433181630644, 2.47374639426837, 2.44524854839106, 
+    28.904814720238, 16.0601313263481, 10.6117049719320, 7.82377531826481, 
+    6.20955682299195, 5.18679961805620, 4.49216000186678, 3.99373973242068, 
+    3.61933010719952, 3.3275594162867, 3.09331226057455, 2.90155994459037, 
+    2.74368539137288, 2.61555847928520, 2.51479444686423, 2.47387109904253, 
+    2.44525093764076, 28.3483300097438, 15.8035063527296, 10.4727953966709, 
+    7.74141823634038, 6.15576314177465, 5.1491550653225, 4.46531988542057, 
+    3.97505189771183, 3.60736868847651, 3.32104702700424, 3.09111342044363, 
+    2.90219825204304, 2.74552084086904, 2.61707392900167, 2.51531961206501, 
+    2.47401179006119, 2.44525268403340, 28.1355600962322, 15.7196640771723, 
+    10.4340722145275, 7.72099712337151, 6.1434091962924, 5.14081963876442, 
+    4.45927409495435, 3.97057677836415, 3.60450193720703, 3.31957820409757, 
+    3.09091185492284, 2.9029090263133, 2.74659551412658, 2.61782756430233, 
+    2.51560631141019, 2.47408801877228, 2.44525363752631), 
+    .Dim = as.integer(c(17, 21))), 
+    
+    Phi2 = structure(c(-0.984831521754346, -0.96178750287388, 
+    -0.925815277018118, -0.877909786944587, -0.820184465666658, 
+    -0.755031918545081, -0.684592921700777, -0.610570901457792, 
+    -0.534175805219629, -0.456236240234657, -0.377306837254648, 
+    -0.297867095171864, -0.218666685919607, -0.141143940005887, 
+    -0.0674987199592516, -0.0328701597273596, -0.00642990194045526, 
+    -0.984833720280198, -0.96124832221758, -0.92402252050786, 
+    -0.87419335313835, -0.81415246030398, -0.74662653505109, 
+    -0.674063099101783, -0.598388680797427, -0.520979416823626, 
+    -0.442739494396008, -0.364272193075272, -0.286088382456793, 
+    -0.208957354222478, -0.1342789733294, -0.0640144100029875, 
+    -0.0311490271069921, -0.006091726394748, -0.979153629182453, 
+    -0.95106168789293, -0.909673941239617, -0.85602448791855, 
+    -0.791828629762056, -0.720369142925194, -0.644748722301942, 
+    -0.567214164881932, -0.489279988980024, -0.411880943403832, 
+    -0.335605401995838, -0.260987626602553, -0.188786833912990, 
+    -0.120269390643364, -0.0570145517746281, -0.0277025095388298, 
+    -0.0054153433806392, -0.956099620177616, -0.91510100889139, 
+    -0.863494586547947, -0.804340589970157, -0.739811913292119, 
+    -0.670992067490536, -0.598508014750715, -0.523938483324115, 
+    -0.449119649196787, -0.375320171482799, -0.303334211640077, 
+    -0.233819259537015, -0.167632931803862, 
+    -0.105970645511563, -0.0499759998221647, -0.0242509183116938, 
+    -0.00473892214395457, -0.91091521430624, -0.854269872890404, 
+    -0.792380659464175, -0.728324327412516, -0.663641470500818, 
+    -0.598766118303959, -0.533390833007158, -0.466958108675312, 
+    -0.399718402638334, -0.332810169846175, -0.267433026630897, 
+    -0.204649764654678, -0.145582752525226, -0.0913961065988934, 
+    -0.042902827489912, -0.0207949382390745, -0.004062467796571, 
+    -0.838142578217344, -0.767730556629547, -0.699387193072487, 
+    -0.634346095207953, -0.572568000770375, -0.513428073110925, 
+    -0.456016815864829, -0.399237447140644, -0.342164056355244, 
+    -0.284798223846443, -0.228151639956042, -0.173628819918976, 
+    -0.122674652213850, -0.0765638152109311, -0.0358016086121756, 
+    -0.0173352283908653, -0.00338423605633909, -0.732960648615699, 
+    -0.655211639338905, -0.586717060962992, -0.525770503418058, 
+    -0.470570307907465, -0.419573011635011, -0.371434023729476, 
+    -0.324886123523844, -0.278750785874156, -0.232309518692667, 
+    -0.185933156371725, -0.140978784025337, -0.0990680854456507, 
+    -0.0615175707971035, -0.0286670029088599, -0.0138724303903631, 
+    -0.00270395845154647, -0.592691443906747, -0.517917221384721, 
+    -0.456902886405761, -0.405327421204478, -0.360251537992231, 
+    -0.319685291504111, -0.282167838420900, -0.246496132463733, 
+    -0.211596523966543, -0.176602222829403, -0.141397972727901, 
+    -0.106937786396409, -0.0748572933895385, -0.0462908166605395, 
+    -0.0215205174484398, -0.0104071747947459, -0.00203767706388774, 
+    -0.418561278354954, -0.359043286074154, -0.313110693536944, 
+    -0.275656631235694, -0.243720459128403, -0.215493360906447, 
+    -0.18976206222188, -0.165585707487220, -0.142157842427747, 
+    -0.118764989711438, -0.0951531051692878, -0.0718822809574559, 
+    -0.0501702371114745, -0.0309413187181704, -0.0143569748225324, 
+    -0.00693928545290556, -0.00135914851834483, -0.217058958479026, 
+    -0.183957984146554, -0.159253973812649, -0.139529858864502, 
+    -0.122956050946611, -0.108468261383110, 
+    -0.095363933833862, -0.0831489044941912, -0.0713807547092049, 
+    -0.0596749091239935, -0.0478406346829651, -0.0361189030171852, 
+    -0.0251638752545685, -0.0154951657479659, -0.00718251696063777, 
+    -0.00347157285038577, -0.000682830247122471, -1.30195010613456e-15, 
+    -7.12101008020212e-16, -9.8472751183435e-16, -1.13492047149954e-15, 
+    -1.21096413626332e-15, -1.05505102779748e-15, -1.11782289130157e-15, 
+    -8.13224377427617e-16, -5.85149540688739e-16, 4.61239028385592e-16, 
+    1.45510576814449e-16, -4.733934001018e-16, -3.36773719381392e-16, 
+    0, 9.23542032962673e-17, -1.87944839722067e-16, -2.8550539469612e-16, 
+    0.217058958479025, 0.183957984146551, 0.159253973812647, 
+    0.139529858864502, 0.12295605094661, 0.108468261383109, 
+    0.0953639338338615, 0.0831489044941909, 0.0713807547092042, 
+    0.0596749091239931, 0.0478406346829641, 0.036118903017185, 
+    0.0251638752545679, 0.0154951657479665, 0.00718251696063749, 
+    0.00347157285038558, 0.00068283024712209, 0.418561278354956, 
+    0.359043286074156, 0.313110693536942, 0.275656631235694, 
+    0.243720459128404, 0.215493360906444, 0.189762062221879, 
+    0.165585707487219, 0.142157842427746, 0.118764989711438, 
+    0.0951531051692875, 0.0718822809574556, 0.0501702371114741, 
+    0.0309413187181703, 0.0143569748225322, 0.00693928545290556, 
+    0.00135914851834492, 0.59269144390675, 0.517917221384721, 
+    0.456902886405764, 0.405327421204478, 0.360251537992232, 
+    0.319685291504111, 0.2821678384209, 0.246496132463732, 
+    0.211596523966543, 0.176602222829402, 0.141397972727901, 
+    0.106937786396409, 0.074857293389538, 0.0462908166605391, 
+    0.0215205174484394, 0.0104071747947454, 0.00203767706388774, 
+    0.7329606486157, 0.655211639338903, 0.58671706096299, 
+    0.525770503418055, 0.470570307907467, 0.419573011635009, 
+    0.371434023729475, 0.324886123523844, 0.278750785874155, 
+    0.232309518692667, 0.185933156371724, 0.140978784025336, 
+    0.0990680854456504, 0.0615175707971032, 0.0286670029088598, 
+    0.0138724303903627, 0.00270395845154656, 0.838142578217343, 
+    0.767730556629544, 0.699387193072486, 0.634346095207951, 
+    0.572568000770374, 0.513428073110924, 0.456016815864827, 
+    0.399237447140644, 0.342164056355244, 0.284798223846443, 
+    0.228151639956042, 0.173628819918976, 0.122674652213850, 
+    0.0765638152109311, 0.0358016086121755, 0.0173352283908648, 
+    0.00338423605633909, 0.910915214306239, 0.854269872890404, 
+    0.792380659464175, 0.728324327412515, 0.663641470500817, 
+    0.598766118303959, 0.533390833007157, 0.466958108675312, 
+    0.399718402638334, 0.332810169846175, 0.267433026630897, 
+    0.204649764654678, 0.145582752525226, 0.0913961065988931, 
+    0.0429028274899118, 0.020794938239074, 0.00406246779657053, 
+    0.956099620177616, 0.915101008891389, 0.863494586547946, 
+    0.804340589970156, 0.739811913292119, 0.670992067490536, 
+    0.598508014750714, 0.523938483324114, 0.449119649196786, 
+    0.375320171482798, 0.303334211640076, 0.233819259537015, 
+    0.167632931803862, 0.105970645511562, 0.0499759998221642, 
+    0.0242509183116936, 0.00473892214395428, 0.979153629182453, 
+    0.95106168789293, 0.909673941239617, 0.85602448791855, 
+    0.791828629762055, 0.720369142925193, 0.644748722301942, 
+    0.567214164881931, 0.489279988980024, 0.411880943403833, 
+    0.335605401995838, 0.260987626602552, 0.188786833912991, 
+    0.120269390643364, 0.0570145517746277, 0.0277025095388299, 
+    0.00541534338063891, 0.984833720280198, 0.96124832221758, 
+    0.92402252050786, 0.87419335313835, 0.81415246030398, 
+    0.746626535051091, 0.674063099101783, 0.598388680797427, 
+    0.520979416823626, 0.442739494396008, 0.364272193075271, 
+    0.286088382456793, 0.208957354222478, 0.1342789733294, 
+    0.0640144100029874, 0.0311490271069919, 0.00609172639474771, 
+    0.984831521754346, 0.96178750287388, 0.925815277018118, 
+    0.877909786944586, 0.820184465666658, 0.75503191854508, 
+    0.684592921700776, 0.610570901457792, 0.534175805219629, 
+    0.456236240234657, 0.377306837254648, 0.297867095171864, 
+    0.218666685919607, 0.141143940005886, 0.0674987199592513, 
+    0.0328701597273591, 0.00642990194045459), 
+    .Dim = as.integer(c(17, 21))), 
+    
+    alpha = c(0.5, 0.6, 0.7, 0.8, 0.9, 1, 1.1, 1.2, 1.3, 1.4, 
+        1.5, 1.6, 1.7, 1.8, 1.9, 1.95, 1.99), 
+        
+    beta = c(-0.95, -0.9, -0.8, -0.7, -0.6, -0.5, -0.4, -0.3, -0.2, -0.1, 
+        0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 0.95)), 
+        
+    .Names = c("Phi1", "Phi2", "alpha", "beta")
+)
+
+
+# ------------------------------------------------------------------------------
+
+
 .qStableFit =
 function(x, doplot = TRUE, title = NULL, description = NULL)
 {   # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Estimates stable parameters by McCulloch approach
+    #   Estimates stable parameters by McCulloch's approach
     
     # Note:
     #   This implementation assumes delta=1 and gamma=0
-    
-    # Changes:
-    #
-    
+       
     # FUNCTION:
     
     # Settings:
     CALL = match.call()
     
     # Load Contour Table:
-    data(PhiStable)
+    # data(PhiStable)
     Phi1 = .PhiStable$Phi1
     Phi2 = .PhiStable$Phi2
     alpha = .PhiStable$alpha
@@ -459,7 +679,7 @@ function(x, doplot = TRUE, title = NULL, description = NULL)
     
     # Add Title and Description:
     if (is.null(title)) title = "Stable Parameter Estimation"
-    if (is.null(description)) description = as.character(date())
+    if (is.null(description)) description = .description()
     
     if (is.na(U) | is.na(V)) {
         GAM = NA
@@ -485,7 +705,7 @@ function(x, doplot = TRUE, title = NULL, description = NULL)
         data = as.data.frame(x),
         fit = fit,
         title = as.character(title), 
-        description = as.character(description) )
+        description = .description() )
 }
 
 
@@ -502,10 +722,7 @@ trace = FALSE, title = NULL, description = NULL)
     
     # Note:
     #   This implementation assumes delta=1 and gamma=0
-    
-    # Changes:
-    #
-    
+   
     # FUNCTION:
     
     # Transform:
@@ -515,6 +732,7 @@ trace = FALSE, title = NULL, description = NULL)
     # Settings:
     CALL = match.call()
     steps <<- 0
+    .trace <<- trace
     
     # Log-likelihood Function:
     establemle = function(x, y = x) { 
@@ -557,13 +775,13 @@ trace = FALSE, title = NULL, description = NULL)
         plot(x, log(y), xlim = c(span[1], span[length(span)]), 
             ylim = ylim, type = "p", xlab = "x", ylab = "log f(x)")
         title("STUDENT-T: Parameter Estimation")
-        lines(x = span, y = log(y.points), col = "steelblue4") 
+        lines(x = span, y = log(y.points), col = "steelblue") 
         if (exists("grid")) grid()  
     }
     
     # Add Title and Description:
     if (is.null(title)) title = "Stable Parameter Estimation"
-    if (is.null(description)) description = as.character(date())
+    if (is.null(description)) description = .description()
         
     # Fit:
     fit = list(estimate = c(alpha = alpha, beta = beta, gamma = gamma, 
@@ -577,11 +795,12 @@ trace = FALSE, title = NULL, description = NULL)
         data = as.data.frame(x.orig),
         fit = fit,
         title = as.character(title), 
-        description = as.character(description) )
+        description = .description() )
 }
 
 
 ################################################################################
+# FUNCTION:            GENERALIZED DISTRIBUTION:
 #  ghFit                Fits parameters of a generalized hyperbolic density
 #  hypFit               Fits parameters of a hyperbolic density
 #  nigFit               Fits parameters of a normal inverse Gaussian density
@@ -594,10 +813,7 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
     
     # Description:
     #   Fits parameters of a generalized hyperbolic density
-
-    # Changes:
-    #
-    
+  
     # FUNCTION:
     
     # Transform:
@@ -665,13 +881,13 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
         plot(x, log(y), xlim = c(span[1], span[length(span)]), 
             ylim = ylim, type = "p", xlab = "x", ylab = "log f(x)", ...)
         title("HYP: Parameter Estimation")    
-        lines(x = span, y = log(y.points), col = "steelblue4")
+        lines(x = span, y = log(y.points), col = "steelblue")
         if (exists("grid")) grid()  
     }
     
     # Add Title and Description:
     if (is.null(title)) title = "Generalized Hyperbolic Parameter Estimation"
-    if (is.null(description)) description = as.character(date())
+    if (is.null(description)) description = .description()
         
     # Fit:
     fit = list(estimate = c(alpha = r$estimate[1], beta = r$estimate[2],
@@ -686,7 +902,7 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
         data = as.data.frame(x.orig),
         fit = fit,
         title = as.character(title), 
-        description = as.character(description) )
+        description = .description() )
 }
 
 
@@ -700,10 +916,7 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
     
     # Description:
     #   Fits parameters of a hyperbolic density 
-
-    # Changes:
-    #
-    
+ 
     # FUNCTION:
     
     # Transform:
@@ -768,13 +981,13 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
         plot(x, log(y), xlim = c(span[1], span[length(span)]), 
             ylim = ylim, type = "p", xlab = "x", ylab = "log f(x)", ...)
         title("HYP: Parameter Estimation")    
-        lines(x = span, y = log(y.points), col = "steelblue4")
+        lines(x = span, y = log(y.points), col = "steelblue")
         if (exists("grid")) grid()  
     }
     
     # Add Title and Description:
     if (is.null(title)) title = "Hyperbolic Parameter Estimation"
-    if (is.null(description)) description = as.character(date())
+    if (is.null(description)) description = .description()
         
     # Fit:
     fit = list(estimate = c(alpha = r$estimate[1], beta = r$estimate[2],
@@ -788,7 +1001,7 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
         data = as.data.frame(x.orig),
         fit = fit,
         title = as.character(title), 
-        description = as.character(description) )
+        description = .description() )
 }
 
 
@@ -803,9 +1016,6 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
     # Description:
     #   Fits parameters of a normal inverse Gaussian density
     
-    # Changes:
-    #
-    
     # FUNCTION:
     
     # Transform:
@@ -860,13 +1070,13 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
         plot(x, log(y), xlim = c(span[1], span[length(span)]), 
             ylim = ylim, type = "p", xlab = "x", ylab = "log f(x)")
         title("NIG: Parameter Estimation")
-        lines(x = span, y = log(y.points), col = "steelblue4") 
+        lines(x = span, y = log(y.points), col = "steelblue") 
         if (exists("grid")) grid() 
     }
     
     # Add Title and Description:
     if (is.null(title)) title = "Normal Inverse Gaussian Parameter Estimation"
-    if (is.null(description)) description = as.character(date())
+    if (is.null(description)) description = .description() 
     
     # Fit:
     fit = list(estimate = r$estimate, minimum = -r$minimum, code = r$code,        
@@ -879,7 +1089,7 @@ span = "auto", trace = FALSE, title = NULL, description = NULL, ...)
         data = as.data.frame(x.orig),
         fit = fit,
         title = as.character(title), 
-        description = as.character(description) )
+        description = .description() )
 }
 
 
