@@ -16,7 +16,7 @@
 
 # Copyrights (C)
 # for this R-port: 
-#   1999 - 2006, Diethelm Wuertz, GPL
+#   1999 - 2007, Diethelm Wuertz, GPL
 #   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
 #   info@rmetrics.org
 #   www.rmetrics.org
@@ -29,7 +29,7 @@
 
 ################################################################################
 # fBasics - A SOFTWARE COLLECTION FOR FINANCIAL ENGINEERS
-# Markets and Basic Statistics
+# Basic Statistics And Return Distributions
 #
 # collected by Diethelm Wuertz
 ################################################################################
@@ -40,30 +40,12 @@ function(lib, pkg)
 {   # A function implemented by Diethelm Wuertz
     
     # Package:
-    cat("\nRmetrics, (C) 1999-2005, Diethelm Wuertz, GPL")
-    cat("\nfBasics: Markets and Basic Statistics\n")
+    cat("\nRmetrics, (C) 1999-2007, Diethelm Wuertz, GPL")
+    cat("\nfBasics: Basic Statistics And Return Distributions\n")
 
     # Load dll:
     library.dynam("fBasics", pkg, lib)
-    
-    # Example time series for internal use:
-    # data(singleIndex.dat)
-    # .univTS = timeSeries(
-    #   data = matrix(singleIndex.dat[, 3], ncol = 1),
-    #   charvec = as.character(singleIndex.dat[, 1]),
-    #   units = "SP500",
-    #   format = "%d-%b-%Y", 
-    #   zone = "GMT",
-    #   FinCenter = "GMT")
-    #.bivTS = timeSeries(
-    #   data = as.matrix(singleIndex.dat[, 2:3]),
-    #   charvec = as.character(singleIndex.dat[, 1]),
-    #   units = c("MSFT", "SP500"),
-    #   format = "%d-%b-%Y", 
-    #   zone = "GMT",
-    #   FinCenter = "GMT")  
-    
-    .Sys.timezone = function() Sys.getenv("TZ")[[1]]
+    # .Sys.timezone = function() Sys.getenv("TZ")[[1]]
 
 }
 
